@@ -20,6 +20,7 @@
 
 #ifndef PAGEPART_H
 #define PAGEPART_H
+#include <iostream>
 
 enum class PagePart
 {
@@ -30,5 +31,9 @@ enum class PagePart
 
 };
 
+std::istream& operator >> ( std::istream& in, PagePart& pagepart );
+std::ostream& operator << ( std::ostream& out, const PagePart& pagepart );
+
+
 
 #endif // PAGEPART_H
