@@ -2,7 +2,7 @@
 #define PDFPAGEREFERENCE_H
 
 #include <QSharedPointer>
-#include <poppler/qt4/poppler-qt4.h>
+#include "poppler-qt.h"
 #include "pdfdocumentreference.h"
 
 /** This holds a reference to a page in a certain document
@@ -12,8 +12,8 @@
  */
 struct PDFPageReference
 {
-  const QSharedPointer<Poppler::Document> document;
-  const QSharedPointer<Poppler::Page> page;
+  const QSharedPointer<const Poppler::Document> document;
+  const QSharedPointer<const Poppler::Page> page;
 
 
   PDFPageReference( const PDFDocumentReference& documentReference, const unsigned int& pageNumber );
