@@ -24,15 +24,21 @@
 #include <QSharedPointer>
 #include "pagepart.h"
 #include <QImage>
-#include <poppler/qt4/poppler-qt4.h>
+#include "poppler-qt.h"
 
 class RenderUtils
 {
 public:
-  static QImage renderPagePart(QSharedPointer<Poppler::Page> page, QSize targetSize, PagePart whichPart);
+  static QImage renderPagePart(QSharedPointer<const Poppler::Page> page, QSize targetSize, PagePart whichPart);
 
   /** Since only the static functions of this class are used, we do not need to construct instances */
   RenderUtils() =delete;
+
+  /** Notifies about impending shutdown.
+   *
+   * All further render attempts will return null images.
+   */
+  static void notifyShutdown(void);
 };
 
 #endif // RENDERUTILS_H
